"""
Copyright 2019, Nils Wenzler, All rights reserved.
nils.wenzler@crowgames.de
"""

import asyncio
import json
import logging
import os
import threading
import time

import websockets


class TestWebSocketServer:

    def scan_trigger(self, websocket):
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)
        result = loop.run_until_complete(self.scan(websocket))

    async def scan(self, websocket):
        while(True):
            try:
                await websocket.send(
                    '{"type":"history","payload":[{"time":1558342186.9478006,"devices":[{"scanning":1,"connections":{"52.222.149.20":{"bsnd":220,"domains":["server-52-222-149-20.fra53.r.cloudfront.net"],"brcv":264,"threats":[],"rcv":4,"snd":4},"40.81.120.44":{"bsnd":206,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":2},"192.168.8.101":{"bsnd":131,"domains":["Crow.lan"],"brcv":260,"threats":[],"rcv":4,"snd":0},"87.253.250.165":{"bsnd":2066,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":14}},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","name":"teclast"},{"scanning":1,"connections":{"192.168.8.101":{"bsnd":17337,"domains":["Crow.lan"],"brcv":24177,"threats":[],"rcv":114,"snd":108}},"ip":"192.168.8.1","osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","name":"console.gl-inet.com","tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}}}],"cidr":"192.168.8.1/24"},{"time":1558342812.3636568,"devices":[{"scanning":1,"connections":{"52.222.149.20":{"bsnd":9838,"domains":["server-52-222-149-20.fra53.r.cloudfront.net"],"brcv":624070,"threats":[],"rcv":420,"snd":166},"192.168.8.1":{"bsnd":290,"domains":["console.gl-inet.com"],"brcv":14978,"threats":[],"rcv":86,"snd":0},"157.55.109.230":{"bsnd":213,"domains":[],"brcv":1519,"threats":[],"rcv":4,"snd":2},"52.222.150.69":{"bsnd":7110,"domains":["server-52-222-150-69.fra53.r.cloudfront.net"],"brcv":211410,"threats":[],"rcv":164,"snd":94},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"172.217.23.142":{"bsnd":330,"domains":["fra16s18-in-f142.1e100.net"],"brcv":396,"threats":[],"rcv":6,"snd":6},"104.25.231.12":{"bsnd":330,"domains":[],"brcv":396,"threats":[{"lists":["threats/malware/hphosts_emd.ipset"]}],"rcv":6,"snd":6},"209.197.3.15":{"bsnd":868,"domains":["vip0x00f.map2.ssl.hwcdn.net"],"brcv":912,"threats":[],"rcv":16,"snd":16},"192.168.8.101":{"bsnd":94,"domains":["Crow.lan"],"brcv":694,"threats":[],"rcv":9,"snd":0},"216.58.208.42":{"bsnd":330,"domains":["fra15s12-in-f10.1e100.net"],"brcv":396,"threats":[],"rcv":6,"snd":6},"216.58.208.35":{"bsnd":1638,"domains":["fra15s12-in-f35.1e100.net"],"brcv":1512,"threats":[],"rcv":24,"snd":30}},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","name":"teclast"},{"scanning":1,"connections":{"192.168.8.101":{"bsnd":17040,"domains":["Crow.lan"],"brcv":25235,"threats":[],"rcv":116,"snd":107},"192.168.8.111":{"bsnd":71,"domains":["teclast.lan"],"brcv":6839,"threats":[],"rcv":90,"snd":0}},"ip":"192.168.8.1","osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","name":"console.gl-inet.com","tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}}}],"cidr":"192.168.8.1/24"},{"time":1558343135.8974333,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 3.0","line":"59506","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 4.3","line":"63833","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"},{"osfamily":"embedded","osgen":null,"cpe":["cpe:/h:asus:rt-n10"],"type":"WAP","vendor":"Asus","accuracy":"93"},{"osfamily":"embedded","osgen":null,"cpe":["cpe:/h:axis:211_network_camera"],"type":"webcam","vendor":"AXIS","accuracy":"93"}],"name":"Asus RT-N10 router or AXIS 211A Network Camera (Linux 2.6)","line":"44656","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","name":"console.gl-inet.com","connections":{"192.168.8.101":{"bsnd":17824,"domains":["Crow.lan"],"brcv":24111,"threats":[],"rcv":119,"snd":115}}}],"cidr":"192.168.8.1/24"},{"time":1558343394.4485023,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","script":{"fingerprint-strings":"\\n  NULL: \\n    SSH-2.0-dropbear\\n    mcurve25519-sha256@libssh.org,diffie-hellman-group14-sha1,diffie-hellman-group1-sha1,kexguess2@matt.ucc.asn.au\\n    ssh-rsa\\n    aes128-ctr,aes256-ctr\\n    aes128-ctr,aes256-ctr\\n    hmac-sha1,hmac-sha2-256\\n    hmac-sha1,hmac-sha2-256\\n    none\\n    none"},"version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","script":{"dns-nsid":"\\n  id.server: FRA"},"version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","script":{"http-server-header":"lighttpd/1.4.48","http-title":"GL.iNet Admin Panel","http-favicon":"Unknown favicon MD5: 59136BAF9ABA0E89D1AC58F147964901","http-methods":"\\n  Supported Methods: OPTIONS GET HEAD POST"},"version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"83":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","script":{"hbase-master-info":"\\n","hadoop-datanode-info":"\\n","http-title":"GL.iNet Admin Panel","hadoop-tasktracker-info":"\\n","http-server-header":"lighttpd/1.4.48","http-favicon":"Unknown favicon MD5: 59136BAF9ABA0E89D1AC58F147964901","hadoop-jobtracker-info":"\\n","http-methods":"\\n  Supported Methods: OPTIONS GET HEAD POST"},"version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.6.25","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.5"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 4.5","line":"64070","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":17056,"domains":["Crow.lan"],"brcv":23586,"threats":[],"rcv":111,"snd":108}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558343493.698158,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","script":{"fingerprint-strings":"\\n  NULL: \\n    SSH-2.0-dropbear\\n    mcurve25519-sha256@libssh.org,diffie-hellman-group14-sha1,diffie-hellman-group1-sha1,kexguess2@matt.ucc.asn.au\\n    ssh-rsa\\n    aes128-ctr,aes256-ctr\\n    aes128-ctr,aes256-ctr\\n    hmac-sha1,hmac-sha2-256\\n    hmac-sha1,hmac-sha2-256\\n    none\\\\n    none"},"version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","script":{"dns-nsid":"\\n  id.server: FRA"},"version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","script":{"http-server-header":"lighttpd/1.4.48","http-title":"GL.iNet Admin Panel","http-favicon":"Unknown favicon MD5: 59136BAF9ABA0E89D1AC58F147964901","http-methods":"\\n  Supported Methods: OPTIONS GET HEAD POST"},"version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"83":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","script":{"hbase-master-info":"\\n","hadoop-datanode-info":"\\n","http-title":"GL.iNet Admin Panel","hadoop-tasktracker-info":"\\n","http-server-header":"lighttpd/1.4.48","http-favicon":"Unknown favicon MD5: 59136BAF9ABA0E89D1AC58F147964901","hadoop-jobtracker-info":"\\n","http-methods":"\\n  Supported Methods: OPTIONS GET HEAD POST"},"version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.6.25","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.5"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 4.5","line":"64070","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":18030,"domains":["Crow.lan"],"brcv":25007,"threats":[],"rcv":119,"snd":113}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558343855.833906,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":29361,"domains":["Crow.lan"],"brcv":28228,"threats":[],"rcv":159,"snd":158}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558349408.405907,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"96"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"96"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.255":{"bsnd":514,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":2},"192.168.8.101":{"bsnd":5970,"domains":["Crow.lan"],"brcv":2514,"threats":[],"rcv":31,"snd":31}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558349619.7844403,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"216.58.207.46":{"bsnd":2450,"domains":["fra16s24-in-f14.1e100.net"],"brcv":10010,"threats":[],"rcv":20,"snd":24},"216.58.206.13":{"bsnd":11892,"domains":["fra16s20-in-f13.1e100.net"],"brcv":864508,"threats":[],"rcv":604,"snd":180},"87.253.250.165":{"bsnd":1958,"domains":[],"brcv":3740,"threats":[],"rcv":14,"snd":12},"172.217.16.206":{"bsnd":3312,"domains":["fra16s08-in-f14.1e100.net"],"brcv":10736,"threats":[],"rcv":26,"snd":26},"172.217.23.174":{"bsnd":2334,"domains":["fra15s22-in-f14.1e100.net"],"brcv":8808,"threats":[],"rcv":20,"snd":22},"172.217.16.142":{"bsnd":1214,"domains":["zrh04s06-in-f142.1e100.net"],"brcv":1358,"threats":[],"rcv":8,"snd":10},"192.168.8.101":{"bsnd":83,"domains":["Crow.lan"],"brcv":746,"threats":[],"rcv":9,"snd":0},"172.217.23.138":{"bsnd":2838,"domains":["fra16s18-in-f10.1e100.net"],"brcv":11296,"threats":[],"rcv":28,"snd":22},"216.58.205.238":{"bsnd":62370,"domains":["fra15s24-in-f14.1e100.net"],"brcv":2919024,"threats":[],"rcv":2095,"snd":886},"192.168.8.1":{"bsnd":107,"domains":["console.gl-inet.com"],"brcv":15309,"threats":[],"rcv":92,"snd":0},"40.81.120.44":{"bsnd":206,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":2},"216.58.208.54":{"bsnd":17000,"domains":["fra15s12-in-f54.1e100.net"],"brcv":393232,"threats":[],"rcv":294,"snd":176},"172.217.22.65":{"bsnd":8890,"domains":["fra15s17-in-f65.1e100.net"],"brcv":67034,"threats":[],"rcv":98,"snd":76},"172.217.21.196":{"bsnd":308,"domains":["fra16s12-in-f4.1e100.net"],"brcv":200,"threats":[],"rcv":2,"snd":4},"172.217.16.131":{"bsnd":7482,"domains":["fra15s46-in-f3.1e100.net"],"brcv":80438,"threats":[],"rcv":82,"snd":52}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":1420,"domains":["Crow.lan"],"brcv":1665,"threats":[],"rcv":10,"snd":3},"192.168.8.111":{"bsnd":70,"domains":["teclast.lan"],"brcv":7710,"threats":[],"rcv":100,"snd":0}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558349768.9013228,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"216.58.207.46":{"bsnd":308,"domains":["fra16s24-in-f14.1e100.net"],"brcv":200,"threats":[],"rcv":2,"snd":4},"172.217.16.206":{"bsnd":308,"domains":["fra16s08-in-f206.1e100.net"],"brcv":200,"threats":[],"rcv":2,"snd":4},"172.217.22.35":{"bsnd":308,"domains":["fra15s16-in-f3.1e100.net"],"brcv":200,"threats":[],"rcv":2,"snd":4},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"216.58.208.54":{"bsnd":308,"domains":["fra15s12-in-f54.1e100.net"],"brcv":308,"threats":[],"rcv":4,"snd":4},"172.217.23.174":{"bsnd":308,"domains":["fra15s22-in-f14.1e100.net"],"brcv":200,"threats":[],"rcv":2,"snd":4},"192.168.8.101":{"bsnd":590,"domains":["Crow.lan"],"brcv":1425,"threats":[],"rcv":9,"snd":0},"216.58.205.238":{"bsnd":5342,"domains":["fra15s24-in-f14.1e100.net"],"brcv":4102,"threats":[],"rcv":38,"snd":22},"129.143.66.13":{"bsnd":125052,"domains":["cache.google.com"],"brcv":10964712,"threats":[],"rcv":7286,"snd":1999},"172.217.16.131":{"bsnd":330,"domains":["zrh04s06-in-f131.1e100.net"],"brcv":396,"threats":[],"rcv":6,"snd":6}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.255":{"bsnd":514,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":2}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558349890.0863016,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"129.143.66.13":{"bsnd":49224,"domains":["cache.google.com"],"brcv":2972180,"threats":[],"rcv":1982,"snd":747},"192.168.8.101":{"bsnd":128,"domains":["Crow.lan"],"brcv":2685,"threats":[],"rcv":7,"snd":0},"216.58.205.238":{"bsnd":5358,"domains":["fra15s24-in-f14.1e100.net"],"brcv":3966,"threats":[],"rcv":36,"snd":22},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"216.58.208.54":{"bsnd":586,"domains":["fra15s12-in-f54.1e100.net"],"brcv":216,"threats":[],"rcv":4,"snd":8}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350000.3815746,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"192.168.8.101":{"bsnd":590,"domains":["Crow.lan"],"brcv":2083,"threats":[],"rcv":8,"snd":0},"216.58.205.238":{"bsnd":3392,"domains":["fra15s24-in-f14.1e100.net"],"brcv":1832,"threats":[],"rcv":22,"snd":14},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"129.143.66.13":{"bsnd":33608,"domains":["cache.google.com"],"brcv":2989240,"threats":[],"rcv":1992,"snd":533}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":1676,"domains":["Crow.lan"],"brcv":548,"threats":[],"rcv":8,"snd":8}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350095.94726,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"192.168.8.101":{"bsnd":83,"domains":["Crow.lan"],"brcv":2696,"threats":[],"rcv":9,"snd":0},"216.58.205.238":{"bsnd":3390,"domains":["fra15s24-in-f238.1e100.net"],"brcv":1832,"threats":[],"rcv":22,"snd":14},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"129.143.66.13":{"bsnd":53666,"domains":["cache.google.com"],"brcv":4010946,"threats":[],"rcv":2667,"snd":850}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350203.0747209,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"192.168.8.101":{"bsnd":590,"domains":["Crow.lan"],"brcv":1096,"threats":[],"rcv":8,"snd":0},"216.58.205.238":{"bsnd":3418,"domains":["fra15s24-in-f14.1e100.net"],"brcv":2032,"threats":[],"rcv":24,"snd":14},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"129.143.66.13":{"bsnd":125440,"domains":["cache.google.com"],"brcv":7362810,"threats":[],"rcv":4888,"snd":1757}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350301.333644,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"192.168.8.1":{"bsnd":337,"domains":["console.gl-inet.com"],"brcv":767,"threats":[],"rcv":4,"snd":0},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"40.81.120.44":{"bsnd":824,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":8},"192.168.8.101":{"bsnd":590,"domains":["Crow.lan"],"brcv":636,"threats":[],"rcv":8,"snd":0},"216.58.205.238":{"bsnd":1996,"domains":["fra15s24-in-f14.1e100.net"],"brcv":970,"threats":[],"rcv":12,"snd":8},"129.143.66.13":{"bsnd":72032,"domains":["cache.google.com"],"brcv":4388626,"threats":[],"rcv":2918,"snd":1091}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":19428,"domains":["Crow.lan"],"brcv":5885,"threats":[],"rcv":70,"snd":68},"192.168.8.111":{"bsnd":84,"domains":["teclast.lan"],"brcv":252,"threats":[],"rcv":4,"snd":0}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350397.2448485,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"92.122.200.66":{"bsnd":324,"domains":["a92-122-200-66.deploy.static.akamaitechnologies.com"],"brcv":324,"threats":[],"rcv":6,"snd":6},"184.31.86.23":{"bsnd":540,"domains":["a184-31-86-23.deploy.static.akamaitechnologies.com"],"brcv":672,"threats":[],"rcv":12,"snd":10},"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"129.143.66.13":{"bsnd":29346,"domains":["cache.google.com"],"brcv":3290856,"threats":[],"rcv":2183,"snd":454},"192.168.8.101":{"bsnd":590,"domains":["Crow.lan"],"brcv":1591,"threats":[],"rcv":8,"snd":0},"65.55.163.91":{"bsnd":54,"domains":[],"brcv":54,"threats":[],"rcv":2,"snd":0},"216.58.205.238":{"bsnd":3654,"domains":["fra15s24-in-f14.1e100.net"],"brcv":2232,"threats":[],"rcv":26,"snd":18}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350506.546188,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"192.168.8.1":{"bsnd":129,"domains":["console.gl-inet.com"],"brcv":411,"threats":[],"rcv":4,"snd":0},"129.143.66.13":{"bsnd":518,"domains":["cache.google.com"],"brcv":6164,"threats":[],"rcv":6,"snd":8},"87.253.250.165":{"bsnd":630,"domains":["no-reverse.nexiu.net"],"brcv":3554,"threats":[],"rcv":12,"snd":6},"173.194.164.140":{"bsnd":80106,"domains":[],"brcv":6547050,"threats":[],"rcv":4568,"snd":1230},"40.81.120.44":{"bsnd":412,"domains":[],"brcv":0,"threats":[],"rcv":0,"snd":4},"192.168.8.101":{"bsnd":208,"domains":["Crow.lan"],"brcv":1226,"threats":[],"rcv":9,"snd":0},"216.58.205.238":{"bsnd":2514,"domains":["fra15s24-in-f238.1e100.net"],"brcv":970,"threats":[],"rcv":12,"snd":8},"172.217.16.131":{"bsnd":5396,"domains":["zrh04s06-in-f131.1e100.net"],"brcv":12054,"threats":[],"rcv":18,"snd":22}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"94","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"94"}],"line":"64106","name":"OpenWrt Designated Driver (Linux 4.1)"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":10561,"domains":["Crow.lan"],"brcv":4486,"threats":[],"rcv":59,"snd":58},"192.168.8.111":{"bsnd":81,"domains":["teclast.lan"],"brcv":243,"threats":[],"rcv":4,"snd":0}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350624.193392,"devices":[{"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[],"mac":"38:1d:d9:0f:52:3c","ip":"192.168.8.111","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"87.253.250.165":{"bsnd":1958,"domains":["no-reverse.nexiu.net"],"brcv":3740,"threats":[],"rcv":14,"snd":12},"192.168.8.101":{"bsnd":83,"domains":["Crow.lan"],"brcv":4130,"threats":[],"rcv":8,"snd":0},"216.58.205.238":{"bsnd":10358,"domains":["fra15s24-in-f14.1e100.net"],"brcv":1832,"threats":[],"rcv":22,"snd":24},"173.194.164.140":{"bsnd":52020,"domains":[],"brcv":3896604,"threats":[],"rcv":2696,"snd":742}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"protocol 2.0","product":"","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","extrainfo":"","product":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","extrainfo":"","product":"lighttpd","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","extrainfo":"workgroup: WORKGROUP","product":"Samba smbd","name":"netbios-ssn","state":"open"}},"location":{"cc":"DE","ip":"141.58.37.74","lat":9.17702,"city":"Stuttgart","lon":48.7823},"scanning":1,"osmatch":[{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"line":"62027","name":"Linux 3.2 - 4.6"},{"accuracy":"97","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"line":"63610","name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"},{"accuracy":"96","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"line":"59506","name":"Linux 3.0"},{"accuracy":"95","osclass":[{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"63833","name":"Linux 4.3"},{"accuracy":"95","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"line":"53646","name":"Linux 2.6.32 - 3.10"},{"accuracy":"94","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"49284","name":"Linux 2.6.24"},{"accuracy":"94","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"line":"60363","name":"Linux 3.10 - 4.2"},{"accuracy":"93","osclass":[{"osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"56098","name":"Linux 2.6.9 - 2.6.18"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"line":"63532","name":"OpenWrt Barrier Breaker (Linux 3.10)"},{"accuracy":"93","osclass":[{"osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"line":"60853","name":"Linux 3.13 - 3.16"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"connections":{"192.168.8.101":{"bsnd":1137,"domains":["Crow.lan"],"brcv":304,"threats":[],"rcv":5,"snd":5}},"name":"console.gl-inet.com","fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350763.1229126,"devices":[{"scanning":1,"location":{"city":"Stuttgart","ip":"141.58.37.74","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":478,"brcv":3977446,"threats":[],"rcv":2758,"bsnd":30994,"domains":[]},"216.58.205.238":{"snd":16,"brcv":2032,"threats":[],"rcv":24,"bsnd":3538,"domains":["fra15s24-in-f14.1e100.net"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"cpe":"","conf":"10","reason":"syn-ack","version":"","product":"","extrainfo":"protocol 2.0","name":"ssh","state":"open"},"53":{"cpe":"","conf":"10","reason":"syn-ack","version":"","product":"","extrainfo":"","name":"domain","state":"open"},"80":{"cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","conf":"10","reason":"syn-ack","version":"1.4.48","product":"lighttpd","extrainfo":"","name":"http","state":"open"},"139":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","product":"Samba smbd","extrainfo":"workgroup: WORKGROUP","name":"netbios-ssn","state":"open"},"445":{"cpe":"cpe:/a:samba:samba","conf":"10","reason":"syn-ack","version":"3.X - 4.X","product":"Samba smbd","extrainfo":"workgroup: WORKGROUP","name":"netbios-ssn","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3"],"osgen":"3.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"},{"cpe":["cpe:/o:linux:linux_kernel:4"],"osgen":"4.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3.18"],"osgen":"3.X","osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"},{"cpe":["cpe:/o:linux:linux_kernel:4.1"],"osgen":"4.X","osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3.0"],"osgen":"3.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:4.3"],"osgen":"4.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:2.6"],"osgen":"2.6.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"},{"cpe":["cpe:/o:linux:linux_kernel:3"],"osgen":"3.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"osgen":"2.6.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3"],"osgen":"3.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"},{"cpe":["cpe:/o:linux:linux_kernel:4"],"osgen":"4.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:2.6"],"osgen":"2.6.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3.10"],"osgen":"3.X","osfamily":"Linux","type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"cpe":["cpe:/o:linux:linux_kernel:3"],"osgen":"3.X","osfamily":"Linux","type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"city":"Stuttgart","ip":"141.58.37.74","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558350869.4041362,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"40.77.226.250":{"snd":4,"brcv":108,"threats":[{"lists":["threats/tracking/hphosts_ats.ipset"]}],"rcv":2,"bsnd":216,"domains":[]},"192.168.8.1":{"snd":0,"brcv":337,"threats":[],"rcv":2,"bsnd":337,"domains":["console.gl-inet.com"]},"92.122.200.66":{"snd":8,"brcv":216,"threats":[],"rcv":4,"bsnd":432,"domains":["a92-122-200-66.deploy.static.akamaitechnologies.com"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":588,"brcv":4077384,"threats":[],"rcv":2829,"bsnd":37196,"domains":[]},"40.81.120.44":{"snd":8,"brcv":0,"threats":[],"rcv":0,"bsnd":824,"domains":[]},"157.55.135.128":{"snd":0,"brcv":54,"threats":[],"rcv":2,"bsnd":54,"domains":[]},"192.168.8.101":{"snd":0,"brcv":1245,"threats":[],"rcv":9,"bsnd":83,"domains":["Crow.lan"]},"216.58.206.14":{"snd":8,"brcv":970,"threats":[],"rcv":12,"bsnd":2002,"domains":["fra16s20-in-f14.1e100.net"]},"52.156.196.151":{"snd":4,"brcv":108,"threats":[],"rcv":2,"bsnd":216,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":0,"brcv":0,"threats":[],"rcv":1,"bsnd":365,"domains":["Crow.lan"]},"192.168.8.111":{"snd":0,"brcv":252,"threats":[],"rcv":4,"bsnd":84,"domains":["teclast.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351017.1830564,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"87.253.250.165":{"snd":12,"brcv":3632,"threats":[],"rcv":12,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"192.168.8.101":{"snd":0,"brcv":1730,"threats":[],"rcv":8,"bsnd":577,"domains":["Crow.lan"]},"216.58.206.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3410,"domains":["fra16s20-in-f14.1e100.net"]},"173.194.164.140":{"snd":246,"brcv":1294870,"threats":[],"rcv":901,"bsnd":17104,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":3,"brcv":160,"threats":[],"rcv":3,"bsnd":665,"domains":["Crow.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351112.3223045,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"40.81.120.44":{"snd":4,"brcv":0,"threats":[],"rcv":0,"bsnd":412,"domains":[]},"172.217.22.14":{"snd":12,"brcv":970,"threats":[],"rcv":12,"bsnd":2272,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":1073,"threats":[],"rcv":7,"bsnd":131,"domains":["Crow.lan"]},"87.253.250.165":{"snd":14,"brcv":3740,"threats":[],"rcv":14,"bsnd":2066,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":1640,"brcv":8492456,"threats":[],"rcv":5878,"bsnd":105514,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351207.2276452,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3408,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.1":{"snd":0,"brcv":473,"threats":[],"rcv":4,"bsnd":237,"domains":["console.gl-inet.com"]},"192.168.8.101":{"snd":0,"brcv":1624,"threats":[],"rcv":7,"bsnd":94,"domains":["Crow.lan"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":316,"brcv":1138288,"threats":[],"rcv":812,"bsnd":23484,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.255":{"snd":2,"brcv":0,"threats":[],"rcv":0,"bsnd":514,"domains":[]},"192.168.8.101":{"snd":2,"brcv":335,"threats":[],"rcv":3,"bsnd":226,"domains":["Crow.lan"]},"192.168.8.111":{"snd":0,"brcv":456,"threats":[],"rcv":6,"bsnd":92,"domains":["teclast.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351315.0852578,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"40.81.120.44":{"snd":4,"brcv":0,"threats":[],"rcv":0,"bsnd":412,"domains":[]},"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3412,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":1163,"threats":[],"rcv":8,"bsnd":83,"domains":["Crow.lan"]},"173.194.164.140":{"snd":750,"brcv":3670576,"threats":[],"rcv":2565,"bsnd":48940,"domains":[]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":26,"brcv":2143,"threats":[],"rcv":28,"bsnd":4994,"domains":["Crow.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351408.9374518,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3368,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":1342,"threats":[],"rcv":5,"bsnd":83,"domains":["Crow.lan"]},"173.194.164.140":{"snd":8,"brcv":456,"threats":[],"rcv":8,"bsnd":496,"domains":[]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351503.6478033,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":16,"brcv":2450,"threats":[],"rcv":24,"bsnd":3888,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":1399,"threats":[],"rcv":9,"bsnd":590,"domains":["Crow.lan"]},"173.194.164.140":{"snd":3142,"brcv":15265582,"threats":[],"rcv":10543,"bsnd":190394,"domains":[]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":64,"brcv":4926,"threats":[],"rcv":64,"bsnd":14762,"domains":["Crow.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351599.8250225,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3384,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.1":{"snd":0,"brcv":2967,"threats":[],"rcv":8,"bsnd":427,"domains":["console.gl-inet.com"]},"40.67.254.36":{"snd":22,"brcv":8502,"threats":[],"rcv":18,"bsnd":2864,"domains":[]},"87.253.250.165":{"snd":14,"brcv":3740,"threats":[],"rcv":14,"bsnd":2066,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":1108,"brcv":4658472,"threats":[],"rcv":3210,"bsnd":77790,"domains":[]},"40.67.251.132":{"snd":20,"brcv":9814,"threats":[],"rcv":20,"bsnd":5264,"domains":[]},"52.113.194.131":{"snd":14,"brcv":1916,"threats":[],"rcv":12,"bsnd":2784,"domains":[]},"192.168.8.101":{"snd":0,"brcv":1222,"threats":[],"rcv":9,"bsnd":82,"domains":["Crow.lan"]},"52.114.77.34":{"snd":54,"brcv":26212,"threats":[],"rcv":34,"bsnd":13136,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":2,"brcv":943,"threats":[],"rcv":4,"bsnd":567,"domains":["Crow.lan"]},"192.168.8.111":{"snd":0,"brcv":1274,"threats":[],"rcv":16,"bsnd":86,"domains":["teclast.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351717.112203,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"40.77.226.250":{"snd":24,"brcv":9774,"threats":[{"lists":["threats/tracking/hphosts_ats.ipset"]}],"rcv":18,"bsnd":7764,"domains":[]},"192.168.8.1":{"snd":0,"brcv":1389,"threats":[],"rcv":4,"bsnd":443,"domains":["console.gl-inet.com"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":222,"brcv":1100462,"threats":[],"rcv":778,"bsnd":15888,"domains":[]},"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3378,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":1655,"threats":[],"rcv":8,"bsnd":83,"domains":["Crow.lan"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":4,"brcv":294,"threats":[],"rcv":5,"bsnd":1991,"domains":["Crow.lan"]},"192.168.8.111":{"snd":0,"brcv":651,"threats":[],"rcv":8,"bsnd":93,"domains":["teclast.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351812.602091,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3380,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":2725,"threats":[],"rcv":8,"bsnd":83,"domains":["Crow.lan"]},"173.194.164.140":{"snd":740,"brcv":4007732,"threats":[],"rcv":2769,"bsnd":47602,"domains":[]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.255":{"snd":2,"brcv":0,"threats":[],"rcv":0,"bsnd":514,"domains":[]},"192.168.8.101":{"snd":4,"brcv":215,"threats":[],"rcv":4,"bsnd":707,"domains":["Crow.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558351908.9067967,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":8,"brcv":970,"threats":[],"rcv":12,"bsnd":1990,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":2650,"threats":[],"rcv":7,"bsnd":94,"domains":["Crow.lan"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":483,"brcv":2569615,"threats":[],"rcv":1780,"bsnd":31600,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558352009.1587207,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":2032,"threats":[],"rcv":24,"bsnd":3404,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.101":{"snd":0,"brcv":2124,"threats":[],"rcv":7,"bsnd":94,"domains":["Crow.lan"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":745,"brcv":3560507,"threats":[],"rcv":2462,"bsnd":47560,"domains":[]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"94"}],"name":"OpenWrt Designated Driver (Linux 4.1)","line":"64106","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":2,"brcv":75,"threats":[],"rcv":2,"bsnd":551,"domains":["Crow.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"},{"time":1558352116.8125806,"devices":[{"scanning":1,"location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"ip":"192.168.8.111","osmatch":[],"mac":"38:1d:d9:0f:52:3c","vendor":{"38:1D:D9:0F:52:3C":"Fn-link Technology Limited"},"connections":{"172.217.22.14":{"snd":14,"brcv":1832,"threats":[],"rcv":22,"bsnd":3382,"domains":["fra16s14-in-f14.1e100.net"]},"192.168.8.1":{"snd":0,"brcv":1219,"threats":[],"rcv":4,"bsnd":385,"domains":["console.gl-inet.com"]},"87.253.250.165":{"snd":12,"brcv":3740,"threats":[],"rcv":14,"bsnd":1958,"domains":["no-reverse.nexiu.net"]},"173.194.164.140":{"snd":534,"brcv":3603680,"threats":[],"rcv":2503,"bsnd":34834,"domains":[]},"40.67.251.132":{"snd":26,"brcv":10486,"threats":[],"rcv":28,"bsnd":5324,"domains":[]},"192.168.8.101":{"snd":0,"brcv":1603,"threats":[],"rcv":8,"bsnd":83,"domains":["Crow.lan"]}},"name":"teclast","fingerprint":1},{"tcp":{"22":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"ssh","extrainfo":"protocol 2.0","state":"open"},"53":{"conf":"10","cpe":"","reason":"syn-ack","product":"","version":"","name":"domain","extrainfo":"","state":"open"},"80":{"conf":"10","cpe":"cpe:/a:lighttpd:lighttpd:1.4.48","reason":"syn-ack","product":"lighttpd","version":"1.4.48","name":"http","extrainfo":"","state":"open"},"139":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"},"445":{"conf":"10","cpe":"cpe:/a:samba:samba","reason":"syn-ack","product":"Samba smbd","version":"3.X - 4.X","name":"netbios-ssn","extrainfo":"workgroup: WORKGROUP","state":"open"}},"scanning":1,"osmatch":[{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"97"}],"name":"Linux 3.2 - 4.6","line":"62027","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.18"],"type":"WAP","vendor":"Linux","accuracy":"97"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.1"],"type":"WAP","vendor":"Linux","accuracy":"97"}],"name":"OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)","line":"63610","accuracy":"97"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.0"],"type":"general purpose","vendor":"Linux","accuracy":"96"}],"name":"Linux 3.0","line":"59506","accuracy":"96"},{"osclass":[{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4.3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 4.3","line":"63833","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"95"},{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"95"}],"name":"Linux 2.6.32 - 3.10","line":"53646","accuracy":"95"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6.24"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 2.6.24","line":"49284","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"94"},{"osfamily":"Linux","osgen":"4.X","cpe":["cpe:/o:linux:linux_kernel:4"],"type":"general purpose","vendor":"Linux","accuracy":"94"}],"name":"Linux 3.10 - 4.2","line":"60363","accuracy":"94"},{"osclass":[{"osfamily":"Linux","osgen":"2.6.X","cpe":["cpe:/o:linux:linux_kernel:2.6"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 2.6.9 - 2.6.18","line":"56098","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3.10"],"type":"WAP","vendor":"Linux","accuracy":"93"}],"name":"OpenWrt Barrier Breaker (Linux 3.10)","line":"63532","accuracy":"93"},{"osclass":[{"osfamily":"Linux","osgen":"3.X","cpe":["cpe:/o:linux:linux_kernel:3"],"type":"general purpose","vendor":"Linux","accuracy":"93"}],"name":"Linux 3.13 - 3.16","line":"60853","accuracy":"93"}],"mac":"E4:95:6E:45:27:92","ip":"192.168.8.1","vendor":{"E4:95:6E:45:27:92":"Ieee Registration Authority"},"name":"console.gl-inet.com","location":{"ip":"141.58.37.74","city":"Stuttgart","lat":9.17702,"cc":"DE","lon":48.7823},"connections":{"192.168.8.101":{"snd":12,"brcv":1250,"threats":[],"rcv":13,"bsnd":2664,"domains":["Crow.lan"]},"192.168.8.111":{"snd":0,"brcv":246,"threats":[],"rcv":4,"bsnd":82,"domains":["teclast.lan"]}},"fingerprint":1}],"cidr":"192.168.8.1/24"}]}')
                await websocket.send(
                    '{"type":"scan_result", "payload":{"devices": [{"location": {"city": "Stuttgart", "ip": "141.58.37.74", "lat": 9.17702, "cc": "DE", "lon": 48.7823}, "scanning": 0, "osmatch": [], "mac": "38:1d:d9:0f:52:3c", "ip": "192.168.8.111", "vendor": {"38:1D:D9:0F:52:3C": "Fn-link Technology Limited"}, "connections": {"40.67.251.132": {"snd": 26, "domains": [], "brcv": 10486, "threats": [], "rcv": 28, "location": {"ip": "40.67.251.132", "city": "Dublin", "lat": -6.26719, "cc": "IE", "lon": 53.344}, "bsnd": 5324}, "87.253.250.165": {"snd": 12, "domains": ["no-reverse.nexiu.net"], "brcv": 3740, "threats": [], "rcv": 14, "location": {"ip": "87.253.250.165", "city": "Stuttgart", "lat": 9.17702, "cc": "DE", "lon": 48.7823}, "bsnd": 1958}, "173.194.164.140": {"snd": 534, "domains": [], "brcv": 3603680, "threats": [], "rcv": 2503, "location": {"ip": "173.194.164.140", "city": "Mountain View", "lat": -122.079, "cc": "US", "lon": 37.406}, "bsnd": 34834}, "192.168.8.1": {"snd": 0, "domains": ["console.gl-inet.com"], "brcv": 1219, "threats": [], "rcv": 4, "location": {"ip": "192.168.8.1", "city": "-", "lat": 0, "cc": "-", "lon": 0}, "bsnd": 385}, "172.217.22.14": {"snd": 14, "domains": ["fra16s14-in-f14.1e100.net"], "brcv": 1832, "threats": [], "rcv": 22, "location": {"ip": "172.217.22.14", "city": "Amsterdam", "lat": 4.88969, "cc": "NL", "lon": 52.374}, "bsnd": 3382}, "192.168.8.101": {"snd": 0, "domains": ["Crow.lan"], "brcv": 1603, "threats": [], "rcv": 8, "location": {"city": "-", "ip": "192.168.8.101", "lat": 0, "cc": "-", "lon": 0}, "bsnd": 83}}, "name": "teclast", "fingerprint": 1}, {"tcp": {"80": {"conf": "10", "cpe": "cpe:/a:lighttpd:lighttpd:1.4.48", "reason": "syn-ack", "version": "1.4.48", "name": "http", "extrainfo": "", "product": "lighttpd", "state": "open"}, "139": {"conf": "10", "cpe": "cpe:/a:samba:samba", "reason": "syn-ack", "version": "3.X - 4.X", "name": "netbios-ssn", "extrainfo": "workgroup: WORKGROUP", "product": "Samba smbd", "state": "open"}, "53": {"conf": "10", "cpe": "", "reason": "syn-ack", "version": "", "name": "domain", "extrainfo": "", "product": "", "state": "open"}, "22": {"conf": "10", "cpe": "", "reason": "syn-ack", "version": "", "name": "ssh", "extrainfo": "protocol 2.0", "product": "", "state": "open"}, "445": {"conf": "10", "cpe": "cpe:/a:samba:samba", "reason": "syn-ack", "version": "3.X - 4.X", "name": "netbios-ssn", "extrainfo": "workgroup: WORKGROUP", "product": "Samba smbd", "state": "open"}}, "location": {"city": "Stuttgart", "ip": "141.58.37.74", "lat": 9.17702, "cc": "DE", "lon": 48.7823}, "scanning": 0, "osmatch": [{"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3"], "type": "general purpose", "vendor": "Linux", "accuracy": "97"}, {"osfamily": "Linux", "osgen": "4.X", "cpe": ["cpe:/o:linux:linux_kernel:4"], "type": "general purpose", "vendor": "Linux", "accuracy": "97"}], "accuracy": "97", "line": "62027", "name": "Linux 3.2 - 4.6"}, {"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3.18"], "type": "WAP", "vendor": "Linux", "accuracy": "97"}, {"osfamily": "Linux", "osgen": "4.X", "cpe": ["cpe:/o:linux:linux_kernel:4.1"], "type": "WAP", "vendor": "Linux", "accuracy": "97"}], "accuracy": "97", "line": "63610", "name": "OpenWrt Chaos Calmer 15.05 (Linux 3.18) or Designated Driver (Linux 4.1)"}, {"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3.0"], "type": "general purpose", "vendor": "Linux", "accuracy": "96"}], "accuracy": "96", "line": "59506", "name": "Linux 3.0"}, {"osclass": [{"osfamily": "Linux", "osgen": "4.X", "cpe": ["cpe:/o:linux:linux_kernel:4.3"], "type": "general purpose", "vendor": "Linux", "accuracy": "95"}], "accuracy": "95", "line": "63833", "name": "Linux 4.3"}, {"osclass": [{"osfamily": "Linux", "osgen": "2.6.X", "cpe": ["cpe:/o:linux:linux_kernel:2.6"], "type": "general purpose", "vendor": "Linux", "accuracy": "95"}, {"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3"], "type": "general purpose", "vendor": "Linux", "accuracy": "95"}], "accuracy": "95", "line": "53646", "name": "Linux 2.6.32 - 3.10"}, {"osclass": [{"osfamily": "Linux", "osgen": "2.6.X", "cpe": ["cpe:/o:linux:linux_kernel:2.6.24"], "type": "general purpose", "vendor": "Linux", "accuracy": "94"}], "accuracy": "94", "line": "49284", "name": "Linux 2.6.24"}, {"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3"], "type": "general purpose", "vendor": "Linux", "accuracy": "94"}, {"osfamily": "Linux", "osgen": "4.X", "cpe": ["cpe:/o:linux:linux_kernel:4"], "type": "general purpose", "vendor": "Linux", "accuracy": "94"}], "accuracy": "94", "line": "60363", "name": "Linux 3.10 - 4.2"}, {"osclass": [{"osfamily": "Linux", "osgen": "2.6.X", "cpe": ["cpe:/o:linux:linux_kernel:2.6"], "type": "general purpose", "vendor": "Linux", "accuracy": "93"}], "accuracy": "93", "line": "56098", "name": "Linux 2.6.9 - 2.6.18"}, {"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3.10"], "type": "WAP", "vendor": "Linux", "accuracy": "93"}], "accuracy": "93", "line": "63532", "name": "OpenWrt Barrier Breaker (Linux 3.10)"}, {"osclass": [{"osfamily": "Linux", "osgen": "3.X", "cpe": ["cpe:/o:linux:linux_kernel:3"], "type": "general purpose", "vendor": "Linux", "accuracy": "93"}], "accuracy": "93", "line": "60853", "name": "Linux 3.13 - 3.16"}], "mac": "E4:95:6E:45:27:92", "ip": "192.168.8.1", "vendor": {"E4:95:6E:45:27:92": "Ieee Registration Authority"}, "connections": {"192.168.8.101": {"snd": 12, "domains": ["Crow.lan"], "brcv": 1250, "threats": [], "rcv": 13, "location": {"ip": "192.168.8.101", "city": "-", "lat": 0, "cc": "-", "lon": 0}, "bsnd": 2664}, "192.168.8.111": {"snd": 0, "domains": ["teclast.lan"], "brcv": 246, "threats": [], "rcv": 4, "location": {"ip": "192.168.8.111", "city": "-", "lat": 0, "cc": "-", "lon": 0}, "bsnd": 82}}, "name": "console.gl-inet.com", "fingerprint": 1}], "cidr": "192.168.8.1/24"}}')

            except TypeError:
                logging.exception("final output type error")
                print(TypeError)
            time.sleep(1)

    async def handle_connection(self, websocket, path):
        try:
            scanning_thread = threading.Thread(target=self.scan_trigger,
                                               args=(websocket,), name="Regular Transmit")
            scanning_thread.start()
            while(True):
                message = await websocket.recv()
                data = json.loads(message)
                if (data["type"] == "kill"):
                    os._exit(1)
        except Exception:
            logging.exception("websocket died")



    def __init__(self):
        logging.info("[*] Start local websocket server for app interaction")
        self.start_server = websockets.serve(self.handle_connection, "localhost", 7463)

        asyncio.get_event_loop().run_until_complete(self.start_server)
        asyncio.get_event_loop().run_forever()



if __name__ == "__main__":
    test = TestWebSocketServer()
    print("test");
